# exp1572
Game "1572: The Lost Expedition" (designed by Mike Heim).

Console game manager written in python. See full description at: https://boardgamegeek.com/boardgame/199269/1572-lost-expedition

Make file exp1572.py executeable and run it for starting the game. All you need for playing: one page with a map (located in the rules/ folder). This program emulate dice rolling and drives a player thru gameplay enforcing rules and context circumstances.

Available localizations: ru, en
